@@ -1,8 +1,9 @@
+#![doc = include_str!("../README.md")]
 #![warn(
     unreachable_pub,
     missing_debug_implementations,
-    // missing_docs,
-    // clippy::pedantic
+    missing_docs,
+    clippy::pedantic
 )]
 use std::{fmt::Display, ops::Deref, str::FromStr};
 
